"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useBalances = void 0;
const objects_1 = require("@hypernetlabs/objects");
const contexts_1 = require("../contexts");
const objects_2 = require("../interfaces/objects");
const react_1 = require("react");
const react_alert_1 = require("react-alert");
const constants_1 = require("../constants");
var EActionTypes;
(function (EActionTypes) {
    EActionTypes["FETCHING"] = "FETCHING";
    EActionTypes["FETCHED"] = "FETCHED";
    EActionTypes["ERROR"] = "ERROR";
    EActionTypes["TOKEN_SELECTED"] = "TOKEN_SELECTED";
})(EActionTypes || (EActionTypes = {}));
function useBalances() {
    const { coreProxy } = contexts_1.useStoreContext();
    const { setLoading } = contexts_1.useLayoutContext();
    const alert = react_alert_1.useAlert();
    react_1.useEffect(() => {
        let cancelRequest = false;
        const fetchData = () => __awaiter(this, void 0, void 0, function* () {
            if (cancelRequest)
                return;
            dispatch({ type: EActionTypes.FETCHING });
            setLoading(true);
            coreProxy === null || coreProxy === void 0 ? void 0 : coreProxy.getBalances().map((balance) => {
                setLoading(false);
                dispatch({
                    type: EActionTypes.FETCHED,
                    payload: balance,
                });
                coreProxy.getPreferredPaymentToken().map((assetInfo) => {
                    console.log("AssetInfo token: ", assetInfo);
                    const tokenName = assetInfo.assetId === constants_1.ETHER_HEX_ADDRESS ? "ETH" : "HyperToken";
                    dispatch({
                        type: EActionTypes.TOKEN_SELECTED,
                        payload: new objects_2.PaymentTokenOptionViewModel(tokenName, assetInfo.assetId),
                    });
                });
            }).mapErr((error) => {
                setLoading(false);
                alert.error(error.message || "An error has happened while pulling balances");
                dispatch({ type: EActionTypes.ERROR, payload: error.message });
            });
        });
        fetchData();
        coreProxy === null || coreProxy === void 0 ? void 0 : coreProxy.onBalancesChanged.subscribe({
            next: (balance) => {
                if (cancelRequest)
                    return;
                dispatch({
                    type: EActionTypes.FETCHED,
                    payload: balance,
                });
            },
        });
        return function cleanup() {
            cancelRequest = true;
        };
    }, []);
    const initialState = {
        error: false,
        loading: true,
        balances: [],
        channelTokenSelectorOptions: [],
        preferredPaymentToken: undefined,
    };
    const [state, dispatch] = react_1.useReducer((state, action) => {
        switch (action.type) {
            case EActionTypes.FETCHING:
                return Object.assign(Object.assign({}, state), { error: false, loading: true });
            case EActionTypes.FETCHED:
                return Object.assign(Object.assign({}, state), { error: false, loading: false, balances: prepareBalances(action.payload), channelTokenSelectorOptions: prepareChannelTokenSelectorOptions(action.payload) });
            case EActionTypes.TOKEN_SELECTED:
                return Object.assign(Object.assign({}, state), { error: false, loading: false, preferredPaymentToken: action.payload });
            case EActionTypes.ERROR:
                return Object.assign(Object.assign({}, state), { error: true, loading: false });
            default:
                return state;
        }
    }, initialState);
    /* const setPreferredPaymentTokenByAssetInfo = (assetInfo: AssetInfo) => {
      if (!assetInfo) {
        alert.error("Token address most be provided!");
        return;
      }
      const tokenName =
        assetInfo.assetId === ETHER_HEX_ADDRESS ? "ETH" : "HyperToken";
      dispatch({
        type: EActionTypes.TOKEN_SELECTED,
        payload: new PaymentTokenOptionViewModel(tokenName, assetInfo.assetId),
      });
    }; */
    const setPreferredPaymentToken = (selectedOption) => {
        if (!(selectedOption === null || selectedOption === void 0 ? void 0 : selectedOption.address)) {
            alert.error("Token address most be provided!");
            return;
        }
        setLoading(true);
        coreProxy
            .setPreferredPaymentToken(objects_1.EthereumAddress(selectedOption.address))
            .match(() => {
            setLoading(false);
            alert.success("Your default payment token has changed!");
            dispatch({
                type: EActionTypes.TOKEN_SELECTED,
                payload: selectedOption,
            });
        }, (err) => {
            setLoading(false);
            alert.error(err.message || "An error occurred while saveing payment token");
            dispatch({ type: EActionTypes.ERROR, payload: err.message });
        });
    };
    function prepareBalances(balance) {
        return balance.assets.reduce((acc, assetBalance) => {
            acc.push(assetBalance);
            return acc;
        }, []);
    }
    function prepareChannelTokenSelectorOptions(balance) {
        return balance.assets.reduce((acc, assetBalance) => {
            const tokenName = assetBalance.assetAddress === constants_1.ETHER_HEX_ADDRESS
                ? "ETH"
                : "HyperToken";
            acc.push(new objects_2.PaymentTokenOptionViewModel(tokenName, assetBalance.assetAddress));
            return acc;
        }, []);
    }
    return Object.assign(Object.assign({}, state), { setPreferredPaymentToken });
}
exports.useBalances = useBalances;
//# sourceMappingURL=useBalances.js.map